Package: MEAL
Title: Perform methylation analysis
Version: 1.43.0
Authors@R: c(person("Carlos", "Ruiz-Arenas", , "carlos.ruiz@isglobal.org", role = c("aut", "cre")),
  person("Juan R.", "Gonzalez", ,"juanr.gonzalez@isglobal.org", role = "aut"))
Maintainer: Xavier Escribà Montagut <xavier.escriba@isglobal.org>
Description: Package to integrate methylation and expression data. It can
    also perform methylation or expression analysis alone. Several plotting
    functionalities are included as well as a new region analysis based on
    redundancy analysis. Effect of SNPs on a region can also be estimated.
Depends: R (>= 3.6.0), Biobase, MultiDataSet
License: Artistic-2.0
biocViews: DNAMethylation, Microarray, Software, WholeGenome
Imports: GenomicRanges, limma, vegan, BiocGenerics, minfi, IRanges,
        S4Vectors, methods, parallel, ggplot2 (>= 2.0.0), permute,
        Gviz, missMethyl, isva, SummarizedExperiment, SmartSVA,
        graphics, stats, utils, matrixStats
Suggests: testthat, IlluminaHumanMethylationEPICanno.ilm10b2.hg19,
        IlluminaHumanMethylation450kanno.ilmn12.hg19, knitr, minfiData,
        BiocStyle, rmarkdown, brgedata
VignetteBuilder: knitr
RoxygenNote: 7.1.1
Encoding: UTF-8
git_url: https://git.bioconductor.org/packages/MEAL
git_branch: devel
git_last_commit: 438858e
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-05-11
NeedsCompilation: no
Packaged: 2026-05-11 22:44:35 UTC; biocbuild
Author: Carlos Ruiz-Arenas [aut, cre],
  Juan R. Gonzalez [aut]
