# Generated by roxygen2: do not edit by hand

export(correlationMethExprs)
export(exportResults)
export(filterResults)
export(getGeneVals)
export(getProbeResults)
export(getRDAresults)
export(plotFeature)
export(plotRDA)
export(plotRegion)
export(runBlockFinder)
export(runBumphunter)
export(runDMRcate)
export(runDiffMeanAnalysis)
export(runDiffVarAnalysis)
export(runPipeline)
export(runRDA)
export(runRegionAnalysis)
export(topRDAhits)
import(Biobase)
import(BiocGenerics)
import(MultiDataSet)
import(methods)
importFrom(GenomicRanges,GRanges)
importFrom(GenomicRanges,end)
importFrom(GenomicRanges,findOverlaps)
importFrom(GenomicRanges,makeGRangesFromDataFrame)
importFrom(GenomicRanges,seqnames)
importFrom(GenomicRanges,start)
importFrom(IRanges,IRanges)
importFrom(S4Vectors,Rle)
importFrom(S4Vectors,queryHits)
importFrom(S4Vectors,runValue)
importFrom(S4Vectors,subjectHits)
importFrom(SummarizedExperiment,assay)
importFrom(ggplot2,aes)
importFrom(ggplot2,aes_string)
importFrom(ggplot2,alpha)
importFrom(ggplot2,facet_grid)
importFrom(ggplot2,geom_bar)
importFrom(ggplot2,geom_errorbar)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_polygon)
importFrom(ggplot2,geom_smooth)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,position_jitter)
importFrom(ggplot2,scale_colour_manual)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme)
importFrom(graphics,legend)
importFrom(graphics,points)
importFrom(graphics,text)
importFrom(limma,contrasts.fit)
importFrom(limma,eBayes)
importFrom(limma,lmFit)
importFrom(limma,topTable)
importFrom(matrixStats,rowVars)
importFrom(minfi,GenomicRatioSet)
importFrom(minfi,blockFinder)
importFrom(minfi,bumphunter)
importFrom(minfi,cpgCollapse)
importFrom(minfi,getBeta)
importFrom(minfi,ilogit2)
importFrom(minfi,logit2)
importFrom(parallel,mclapply)
importFrom(permute,how)
importFrom(stats,contrasts)
importFrom(stats,cor.test)
importFrom(stats,formula)
importFrom(stats,lm)
importFrom(stats,model.matrix)
importFrom(stats,p.adjust)
importFrom(stats,prcomp)
importFrom(stats,qbeta)
importFrom(stats,qt)
importFrom(utils,write.csv2)
importFrom(vegan,RsquareAdj)
importFrom(vegan,anova.cca)
importFrom(vegan,ordilabel)
importFrom(vegan,rda)
