#' Defunct functions 
#' 
#' These functions are defunct and no longer available.
#' 
#' @name MEAL-defunct
#' 
#' @details Defunct functions are: multiCorrMethExprs, DAPipeline, DAProbe, DARegion, 
#' RDAset, filterSet, plotBestFeatures, preparePhenotype, createRanges, prepareMethylationSet,
#' calculateRelevantSNPs, correlationMethSNPs, explainedVariance, normalSNP, plotLM
#' 
#' Defunct classes are: analysisRegionResults, analysisResults
NULL